==> TuxGuitar-0.7-src.tar.gz: TuxGuitar-0.7-src/src/org/herac/tuxguitar/gui/actions/duration/SetWholeDurationAction.java <==
/*
 * Created on 17-dic-2005
 *
 * TODO To change the template for this generated file go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
package org.herac.tuxguitar.gui.actions.duration;

import org.eclipse.swt.events.TypedEvent;
import org.herac.tuxguitar.gui.TablatureEditor;
import org.herac.tuxguitar.gui.actions.Action;
import org.herac.tuxguitar.gui.tab.Caret;
import org.herac.tuxguitar.gui.undo.undoables.component.UndoableComponentGeneric;
import org.herac.tuxguitar.song.models.Duration;

/**
 * @author julian
 *
 * TODO To change the template for this generated type comment go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
public class SetWholeDurationAction extends Action{
    public static final String NAME = "SET_WHOLE_DURATION";    
    public static final int VALUE = Duration.WHOLE;

    
    public SetWholeDurationAction(TablatureEditor tablatureEditor) {
        super(NAME,tablatureEditor);       
    }

    public boolean doAction(TypedEvent e) {
        //comienza el undoable
    	UndoableComponentGeneric undoable = UndoableComponentGeneric.startUndo(); 
        
        getSelectedDuration().setValue(VALUE);
        setDurations();
        
        //termia el undoable
        getEditor().getUndoManager().addEdit(undoable.endUndo()); 
        
        return true;
    }
    
    private void setDurations() {
        Caret caret = getEditor().getTablature().getCaret();            
        caret.changeDuration((Duration)getSelectedDuration().clone());
        fireUpdate(getEditor().getTablature().getCaret().getMeasureCoords().getMeasure().getNumber());
        redraw();
    }
    
    public Duration getSelectedDuration(){
        return getEditor().getTablature().getCaret().getDuration();
    }     


}

==> TuxGuitar-0.8-src.tar.gz: TuxGuitar-0.8-src/src/org/herac/tuxguitar/gui/actions/duration/SetWholeDurationAction.java <==
/*
 * Created on 17-dic-2005
 *
 * TODO To change the template for this generated file go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
package org.herac.tuxguitar.gui.actions.duration;

import org.eclipse.swt.events.TypedEvent;
import org.herac.tuxguitar.gui.TablatureEditor;
import org.herac.tuxguitar.gui.actions.Action;
import org.herac.tuxguitar.gui.tab.Caret;
import org.herac.tuxguitar.gui.undo.undoables.component.UndoableComponentGeneric;
import org.herac.tuxguitar.song.models.Duration;

/**
 * @author julian
 *
 * TODO To change the template for this generated type comment go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
public class SetWholeDurationAction extends Action{
    public static final String NAME = "SET_WHOLE_DURATION";    
    public static final int VALUE = Duration.WHOLE;

    
    public SetWholeDurationAction(TablatureEditor tablatureEditor) {
        super(NAME,tablatureEditor);       
    }

    public boolean doAction(TypedEvent e) {
    	if(getSelectedDuration().getValue() != VALUE){
        //comienza el undoable
    	UndoableComponentGeneric undoable = UndoableComponentGeneric.startUndo(); 
        
        getSelectedDuration().setValue(VALUE);
        getSelectedDuration().setDotted(false);
        getSelectedDuration().setDoubleDotted(false);
        //getSelectedDuration().getTupleto().setEnters(1);
        //getSelectedDuration().getTupleto().setTimes(1);        
        setDurations();
        
        //termia el undoable
        getEditor().getUndoManager().addEdit(undoable.endUndo()); 
    	}
        return true;
    }
    
    private void setDurations() {
        Caret caret = getEditor().getTablature().getCaret();            
        caret.changeDuration((Duration)getSelectedDuration().clone());
        fireUpdate(getEditor().getTablature().getCaret().getMeasureCoords().getMeasure().getNumber());
        redraw();
    }
    
    public Duration getSelectedDuration(){
        return getEditor().getTablature().getCaret().getDuration();
    }     


}
